%%This code will allow you to calculated the average correlated motion of
%%neighboring chromatid strands linked with cohesin, strands that are not
%%linked by cohesin, and sister strands.  This code requires the coord_summ
%%folder containing the 64 coordinate summary files.  Be aware that the
%%bead number in the chromoShake outfiles are inversely correlated with the
%%number of the coord_summ CSV file.

%%Select the coordinate summary folder.
pathname=uigetdir('Z:\Josh\~ChromoShake_Paper\ChromoShake_Data\CentromereModels\5000_trim\5000trimmed_MSD_analysis\','Pick the files');
fileList = dir(pathname);
for n = 1:64
    fileName = strcat(pathname,'\','coord_summ',num2str(n),'.csv');
    matrix(:,:,n) = csvread(fileName,1,0);
end
%%Trim selected number of timepoints from the simulation
[time,~,~] = size(matrix);
prompt = ['Your files have',' ', num2str(time),' ', 'timepoints. How many initial timepoints should we disregard?\n'];
offset = input(prompt);
matrix = matrix((offset + 1):end,:,:);
%% Calculate and display the average correlation coefficient of the neighboring strands linked with coheisn
for i = 1:32
    if i <= 30
        corrMatX = corrcoef(matrix(:,2,i),matrix(:,2,(i+34)));
        corrMatY = corrcoef(matrix(:,3,i),matrix(:,3,(i+34)));
        corrMatZ = corrcoef(matrix(:,4,i),matrix(:,4,(i+34)));
    else
        corrMatX = corrcoef(matrix(:,2,i),matrix(:,2,(i+2)));
        corrMatY = corrcoef(matrix(:,3,i),matrix(:,3,(i+2)));
        corrMatZ = corrcoef(matrix(:,4,i),matrix(:,4,(i+2)));
    end
    %Corrcoef creates a 2x2 matrix. This selects the proper value.
    corrX(i) = corrMatX(1,2);
    corrY(i) = corrMatY(1,2);
    corrZ(i) = corrMatZ(1,2);
end
%calculate the means
meanX = mean(corrX);
meanY = mean(corrY);
meanZ = mean(corrZ);
%calculate the standard deviations
stdX = std(corrX);
stdY = std(corrY);
stdZ = std(corrZ);
%display the mean and standard deviations for the cohesin-linked neighbors
disp('Cohesin Neighbors:');
disp(strcat('X: ',num2str(meanX), ' ',' ', num2str(stdX)));
disp(strcat('Y: ',num2str(meanY), ' ',' ', num2str(stdY)));
disp(strcat('Z: ',num2str(meanZ), ' ',' ', num2str(stdZ)));
%% Calculate and display the average correlation coefficient of the neighboring strands not linked with coheisn
for i = 1:32
    corrMatX_strand = corrcoef(matrix(:,2,i),matrix(:,2,(i+32)));
    corrMatY_strand = corrcoef(matrix(:,3,i),matrix(:,3,(i+32)));
    corrMatZ_strand = corrcoef(matrix(:,4,i),matrix(:,4,(i+32)));
    
    corrX_strand(i) = corrMatX_strand(1,2);
    corrY_strand(i) = corrMatY_strand(1,2);
    corrZ_strand(i) = corrMatZ_strand(1,2);
end

meanX_strand = mean(corrX_strand);
meanY_strand = mean(corrY_strand);
meanZ_strand = mean(corrZ_strand);

stdX_strand = std(corrX_strand);
stdY_strand = std(corrY_strand);
stdZ_strand = std(corrZ_strand);

disp('Unlinked Neighbors:');
disp(strcat('X: ',num2str(meanX_strand), ' ',' ', num2str(stdX_strand)));
disp(strcat('Y: ',num2str(meanY_strand), ' ',' ', num2str(stdY_strand)));
disp(strcat('Z: ',num2str(meanZ_strand), ' ',' ', num2str(stdZ_strand)));
%% Calculate and display the average correlation coefficient of sister strands
for i = 1:32
    iMod = mod(i,2);
    if iMod == 1
        
        corrMatX_sister = corrcoef(matrix(:,2,i),matrix(:,2,(i+1)));
        corrMatY_sister = corrcoef(matrix(:,3,i),matrix(:,3,(i+1)));
        corrMatZ_sister = corrcoef(matrix(:,4,i),matrix(:,4,(i+1)));
    else
        corrMatX_sister = corrcoef(matrix(:,2,i),matrix(:,2,(i-1)));
        corrMatY_sister = corrcoef(matrix(:,3,i),matrix(:,3,(i-1)));
        corrMatZ_sister = corrcoef(matrix(:,4,i),matrix(:,4,(i-1)));
    end
    
    corrX_sister(i) = corrMatX_sister(1,2);
    corrY_sister(i) = corrMatY_sister(1,2);
    corrZ_sister(i) = corrMatZ_sister(1,2);
end

meanX_sister = mean(corrX_sister);
meanY_sister = mean(corrY_sister);
meanZ_sister = mean(corrZ_sister);

stdX_sister = std(corrX_sister);
stdY_sister = std(corrY_sister);
stdZ_sister = std(corrZ_sister);

disp('Sisters:');
disp(strcat('X: ',num2str(meanX_sister), ' ',' ', num2str(stdX_sister)));
disp(strcat('Y: ',num2str(meanY_sister), ' ',' ', num2str(stdY_sister)));
disp(strcat('Z: ',num2str(meanZ_sister), ' ',' ', num2str(stdZ_sister)));
%% Creating the 3D surface graph
% I need to create a 64x64 matrix of all the correlation values

% calculate all the correlation values

for i = 1:64
    for j = 1:64
        corrMatX_total = corrcoef(matrix(:,2,i),matrix(:,2,j));
        corrMatY_total = corrcoef(matrix(:,3,i),matrix(:,3,j));
        corrMatZ_total = corrcoef(matrix(:,4,i),matrix(:,4,j));  
        
        corrX_total(i,j) = corrMatX_total(1,2);
        corrY_total(i,j) = corrMatY_total(1,2);
        corrZ_total(i,j) = corrMatZ_total(1,2);
    end
end
%create the surf graph of all the Z correlation coefficients
clf;
surf(corrZ_total);
